# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::macGreek;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InMacGreek{
	return <<'END';
0	7E
A0
A3
A5	A9
AB	AE
B0	B3
B7
B9
BB
BD
C4
C9
D6
DC
DF	E0
E2
E4
E7	EB
EE	EF
F4
F6	F7
F9
FB	FC
153
384	386
388	38A
38C
38E	3A1
3A3	3CE
2013
2015
2018	2019
201C	201D
2020
2022
2026
2030
2122
2248
2260
2264	2265
F8A0
END
}
1;
__END__
