# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::8859_6;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InISO_8859_6{
	return <<'END';
0	2F
3A	A0
A4
AD
60C
61B
61F
621	63A
640	652
660	669
END
}
1;
__END__
