# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::8859_2;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InISO_8859_2{
	return <<'END';
0	A0
A4
A7	A8
AD
B0
B4
B8
C1	C2
C4
C7
C9
CB
CD	CE
D3	D4
D6	D7
DA
DC	DD
DF
E1	E2
E4
E7
E9
EB
ED	EE
F3	F4
F6	F7
FA
FC	FD
102	107
10C	111
118	11B
139	13A
13D	13E
141	144
147	148
150	151
154	155
158	15B
15E	165
16E	171
179	17E
2C7
2D8	2D9
2DB
2DD
END
}
1;
__END__
