# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::viscii;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InVISCII{
	return <<'END';
0	1
3	4
7	13
15	18
1A	1D
1F	7F
C0	C3
C8	CA
CC	CD
D2	D5
D9	DA
DD
E0	E3
E8	EA
EC	ED
F2	F5
F9	FA
FD
102	103
110	111
128	129
168	169
1A0	1A1
1AF	1B0
1EA0	1EA8
1EAA	1EF9
END
}
1;
__END__
