# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::macCyrillic;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InMacCyrillic{
	return <<'END';
0	7E
A0
A3
A7
A9
AB	AC
AE
B0	B1
B5	B6
BB
F7
192
401	40C
40E	44F
451	45C
45E	45F
490	491
2013	2014
2018	2019
201C	201E
2020
2022
2026
20AC
2116
2122
2206
221A
221E
2248
2260
2264	2265
END
}
1;
__END__
