# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::8859_11;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InISO_8859_11{
	return <<'END';
0	A0
DB	DE
FC	FF
E01	E3A
E3F	E5B
END
}
1;
__END__
