# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::8859_16;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InISO_8859_16{
	return <<'END';
0	A0
A7
A9
AB
AD
B0	B1
B6	B7
BB
C0	C2
C4
C6	CF
D2	D4
D6
D9	DC
DF	E2
E4
E6	EF
F2	F4
F6
F9	FC
FF
102	107
10C	10D
110	111
118	119
141	144
150	153
15A	15B
160	161
170	171
178	17E
218	21B
201D	201E
20AC
END
}
1;
__END__
