# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::cp1026;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InCP1026{
	return <<'END';
0	CF
D1	DC
DF	EF
F1	FC
FF
11E	11F
130	131
15E	15F
END
}
1;
__END__
