# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::cp424;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InCP424{
	return <<'END';
0	A0
A2	A9
AB	B9
BB	BE
D7
F7
5D0	5EA
2017
END
}
1;
__END__
