# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::cp1255;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InCP1255{
	return <<'END';
0	7F
A0	A3
A5	A9
AB	B9
BB	BF
D7
F7
192
2C6
2DC
5B0	5B9
5BB	5C3
5D0	5EA
5F0	5F4
200E	200F
2013	2014
2018	201A
201C	201E
2020	2022
2026
2030
2039	203A
20AA
20AC
2122
END
}
1;
__END__
