# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::gsm0338;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InGSM0338{
	return <<'END';
A
D
20	5A
5F
61	7A
A0	A1
A3	A5
A7
BF
C4	C6
C9
D1
D6
D8
DC
DF	E0
E4	E9
EC
F1	F2
F6
F8	F9
FC
393	394
398
39B
39E
3A0
3A3
3A6
3A8	3A9
END
}
1;
__END__
