# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::macHebrew;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InMacHebrew{
	return <<'END';
0	1F
26
40	5A
5C
5E	7A
7E
C4
C7
C9
D1
D6
DC
E0	E5
E7	EF
F1	F6
F9	FC
5B0	5B9
5BB	5BC
5BF
5D0	5EA
20AA
F86A
F89B	F89E
FB1F
FB2A	FB2B
FB35
FB4B
END
}
1;
__END__
