# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::cp875;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InCP875{
	return <<'END';
0	A0
A3
A6	A9
AB	AD
B0	B4
BB
BD
385	38A
38C
38E	3A1
3A3	3CE
2015
2018	2019
END
}
1;
__END__
