# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::8859_3;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InISO_8859_3{
	return <<'END';
0	A0
A3	A4
A7	A8
AD
B0
B2	B5
B7	B8
BD
C0	C2
C4
C7	CF
D1	D4
D6	D7
D9	DC
DF	E2
E4
E7	EF
F1	F4
F6	F7
F9	FC
108	10B
11C	121
124	127
130	131
134	135
15C	15F
16C	16D
17B	17C
2D8	2D9
END
}
1;
__END__
