# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::8859_7;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InISO_8859_7{
	return <<'END';
0	A0
A3
A6	A9
AB	AD
B0	B3
B7
BB
BD
2BC	2BD
384	386
388	38A
38C
38E	3A1
3A3	3CE
2015
END
}
1;
__END__
