# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::ascii;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InASCII{
	return <<'END';
0	7F
END
}
1;
__END__
