# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::nextstep;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InNextstep{
	return <<'END';
0	1F
A0	AC
AE	AF
B1	FF
131
141	142
152	153
192
2C6	2C7
2CB
2D8	2DD
2013	2014
2019	201A
201C	201E
2020	2022
2026
2030
2039	203A
2044
FB01	FB02
FFFD
END
}
1;
__END__
