# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::8859_15;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InISO_8859_15{
	return <<'END';
0	A3
A5
A7
A9	B3
B5	B7
B9	BB
BF	FF
152	153
160	161
178
17D	17E
20AC
END
}
1;
__END__
