# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::macArabic;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InMacArabic{
	return <<'END';
0	1F
30	39
40	5A
60	7A
7E
C4
C7
C9
D1
D6
DC
E0	E2
E4
E7	EB
ED	EF
F1
F3	F4
F6
F9	FC
60C
61B
61F
621	63A
640	652
66A
679
67E
686
688
691
698
6A4
6AF
6BA
6D2
6D5
END
}
1;
__END__
