# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::8859_14;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InISO_8859_14{
	return <<'END';
0	A0
A3
A7
A9
AD	AE
B6
C0	CF
D1	D6
D8	DD
DF	EF
F1	F6
F8	FD
FF
10A	10B
120	121
174	178
1E02	1E03
1E0A	1E0B
1E1E	1E1F
1E40	1E41
1E56	1E57
1E60	1E61
1E6A	1E6B
1E80	1E85
1EF2	1EF3
END
}
1;
__END__
