# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::macThai;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InMacThai{
	return <<'END';
0	7E
A0
A9
AB
AE
BB
E01	E3A
E3F	E4D
E4F	E59
200B
2013	2014
2018	2019
201C	201D
2022
2026
2122
FEFF
END
}
1;
__END__
