# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::adobeStdenc;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InAdobeStandardEncoding{
	return <<'END';
0	7E
A0	A5
A7	A8
AA	AB
AD
AF
B4
B6	B8
BA	BB
BF
C6
D8
DF
E6
F8
131
141	142
152	153
192
2C6	2C7
2C9
2D8	2DD
2013	2014
2018	201A
201C	201E
2020	2022
2026
2030
2039	203A
2044
2215
2219
FB01	FB02
END
}
1;
__END__
