# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::cp864;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InCP864{
	return <<'END';
0	24
26	7F
A0
A2	A4
A6
AB	AD
B0	B1
B7
BB	BD
D7
F7
3B2
3C6
60C
61B
61F
640
651
660	66A
2219	221A
221E
2248
2500
2502
250C
2510
2514
2518
251C
2524
252C
2534
253C
2592
25A0
FE7D
FE80	FE85
FE8B
FE8D	FE8F
FE91
FE93
FE95
FE97
FE99
FE9B
FE9D
FE9F
FEA1
FEA3
FEA5
FEA7
FEA9
FEAB
FEAD
FEAF
FEB1
FEB3
FEB5
FEB7
FEB9
FEBB
FEBD
FEBF
FEC1
FEC5
FEC9	FED1
FED3
FED5
FED7
FED9
FEDB
FEDD
FEDF
FEE1
FEE3
FEE5
FEE7
FEE9
FEEB	FEED
FEEF	FEF3
FEF5	FEF8
FEFB	FEFC
END
}
1;
__END__
