# This is auto-generated.  Do not edit by hand!
package Encode::InCharset::hp_roman8;
our $VERSION = do {my @r = (q$Revision: 0.1 $ =~ /\d+/g); sprintf "%d."."%02d"x$#r, @r};
sub InHp_Roman8{
	return <<'END';
0	A5
A7	A8
AA	AB
AF	B1
B4	B7
BA	D6
D8	F6
F8	FF
160	161
178
192
2C6
2CB
2DC
2014
20A4
25A0
END
}
1;
__END__
